Change log
========================

Version 0.1.1 (2014-09-16)

* fix xml encoding. This brings dramatic speedups when downloading and parsing data
* extend dexcription.rst


Version 0.1 (2014-09-07)

initial release
